# wallhaven-dl

Download wallpaper from wallhaven.cc

## Installation

```bash
pip install wallhaven-dl
```

## Usage

```bash
wallhaven_dl -h
```

![](https://s1.vika.cn/space/2022/10/07/52c247f16fa54cf0819ca889feab0562)
